@@ -2,7 +2,10 @@
 #
 # action.rb -- IKEGAMI Daisuke
 # original is http://ming.sourceforge.net/examples/example.php?name=action
-# $Log$
+# $Log: action.rb,v $
+# Revision 1.1  2004/10/31 13:52:10  ikegami
+# initial commit
+#
 
 require 'ming/ming'
 include Ming
@@ -18,7 +21,7 @@ s.draw_line_to(25, 25)
 s.draw_line_to(-25, 25)
 s.draw_line_to(-25, -25)
 
-p = SWFSprite.new
+p = SWFMovieClip.new
 i = p.add(s)
 i.set_depth(1)
 p.next_frame
