@@ -2,7 +2,11 @@
 #
 # gradient.rb -- IKEGAMI Daisuke
 # original is http://ming.sourceforge.net/examples/example.php?name=gradient
-# $Log$
+# $Log: gradient.rb,v $
+# Revision 1.1  2004/11/07 17:34:22  ikegami
+# NEWS: version 0.1.7 shipped.
+# some bugs are fixed, and it seems work with Ming 0.3beta1.
+#
 
 require 'ming/ming'
 include Ming
@@ -19,7 +23,7 @@ g = SWFGradient.new
 g.add_entry(0.0, 0, 0, 0)
 g.add_entry(1.0, 0xff, 0xff, 0xff)
 
-f = s.add_fill(g, SWFFILL_LINEAR_GRADIENT)
+f = s.add_gradient_fill(g, SWFFill::LINEAR_GRADIENT)
 f.scale_to(0.17)
 f.move_to(160, 120)
 s.set_right_fill(f)
@@ -37,7 +41,7 @@ g = SWFGradient.new
 g.add_entry(0.0, 0xff, 0, 0, 0xff)
 g.add_entry(1.0, 0xff, 0, 0, 0)
 
-f = s.add_fill(g, SWFFILL_RADIAL_GRADIENT)
+f = s.add_fill(g, SWFFill::RADIAL_GRADIENT)
 f.scale_to(0.12)
 f.move_to(160, 120)
 s.set_right_fill(f)
