@@ -2,7 +2,11 @@
 #
 # gradientxform.rb -- IKEGAMI Daisuke
 # original is http://ming.sourceforge.net/examples/example.php?name=gradientxform
-# $Log$
+# $Log: gradientxform.rb,v $
+# Revision 1.1  2004/11/07 17:34:22  ikegami
+# NEWS: version 0.1.7 shipped.
+# some bugs are fixed, and it seems work with Ming 0.3beta1.
+#
 
 require 'ming/ming'
 include Ming
@@ -19,7 +23,7 @@ g.add_entry(0.80, 0xff, 0xff, 0xff)
 g.add_entry(1.00, 0, 0, 0)
 
 s = p.get_shape1
-f = s.add_fill(g, SWFFILL_RADIAL_GRADIENT)
+f = s.add_fill(g, SWFFill::RADIAL_GRADIENT)
 f.scale_to(0.1)
 s.set_left_fill(f)
 s.move_pen_to(-160, -120)
@@ -38,7 +42,7 @@ g.add_entry(0.80, 0, 0, 0xff)
 g.add_entry(1.00, 0, 0, 0)
 
 s = p.get_shape2
-f = s.add_fill(g, SWFFILL_RADIAL_GRADIENT)
+f = s.add_fill(g, SWFFill::RADIAL_GRADIENT)
 f.scale_to(0.16)
 f.skew_x_to(-0.5)
 s.set_left_fill(f)
