@@ -2,19 +2,23 @@
 #
 # keypress.rb -- IKEGAMI Daisuke
 #
-# $Log$
+# $Log: keypress.rb,v $
+# Revision 1.1  2004/11/07 17:34:22  ikegami
+# NEWS: version 0.1.7 shipped.
+# some bugs are fixed, and it seems work with Ming 0.3beta1.
+#
 
 require 'ming/ming'
 include Ming
 
-p = SWFSprite.new
+p = SWFMovieClip.new
 p.add(SWFAction.new('stop();'))
 
 chars = 'abcdefghijklmnopqrstuvwxyz' +
         'ABCDEFGHIJKLMNOPQRSTUVWXYZ' +
         '1234567890!@#$%^&*()_+-=/[]{}|;:,.<>?`~'
 
-f = SWFFont.new('_serif')
+f = SWFBrowserFont.new('_serif')
 
 i = nil
 chars.length.times do |n|
@@ -24,7 +28,7 @@ chars.length.times do |n|
   t.set_font(f)
   t.set_height(240)
   t.set_bounds(600, 240)
-  t.align(SWFTEXTFIELD_ALIGN_CENTER)
+  t.set_alignment(SWFTextField::ALIGN_CENTER)
   t.add_string(c)
   i = p.add(t)
   p.label_frame(c)
@@ -39,11 +43,11 @@ s.draw_line(-600, 0)
 s.draw_line(0, -400)
 
 b = SWFButton.new
-b.add_shape(s, SWFBUTTON_HIT)
+b.add_shape(s, SWFButton::HIT)
 
 chars.length.times do |n|
   c = chars[n].chr
-  b.add_action(SWFAction.new("setTarget('/char'); gotoFrame('#{c}');"), key_press(c))
+  b.add_action(SWFAction.new("setTarget('/char'); gotoFrame('#{c}');"), SWFButton::key_press(c))
 end
 
 m = SWFMovie.new
